public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH 1/2] dcdbas: Export functionality for use in other drivers
@ 2008-11-27 16:33 Matthew Garrett
  2008-11-27 16:34 ` [PATCH 2/2] misc: Add dell-laptop driver Matthew Garrett
  2008-12-02  3:52 ` [PATCH 1/2] dcdbas: Export functionality for use in other drivers Greg KH
  0 siblings, 2 replies; 20+ messages in thread
From: Matthew Garrett @ 2008-11-27 16:33 UTC (permalink / raw)
  To: linux-kernel; +Cc: Matt_Domsch, greg

dcdbas: Export functionality for use in other drivers
    
The dcdbas code allows calls to be made into the firmware on Dell 
systems. Exporting this to other drivers allows them to implement 
Dell-specific functionality in a safe way.
    
Signed-off-by: Matthew Garrett <mjg@redhat.com>

diff --git a/drivers/firmware/dcdbas.h b/drivers/firmware/dcdbas.h
index 87bc341..ca3cb0a 100644
--- a/drivers/firmware/dcdbas.h
+++ b/drivers/firmware/dcdbas.h
@@ -101,5 +101,7 @@ struct apm_cmd {
 	} __attribute__ ((packed)) parameters;
 } __attribute__ ((packed));
 
+int dcdbas_smi_request(struct smi_cmd *smi_cmd);
+
 #endif /* _DCDBAS_H_ */
 
diff --git a/drivers/firmware/dcdbas.c b/drivers/firmware/dcdbas.c
index 50a071f..45f109d 100644
--- a/drivers/firmware/dcdbas.c
+++ b/drivers/firmware/dcdbas.c
@@ -238,11 +238,11 @@ static ssize_t host_control_on_shutdown_store(struct device *dev,
 }
 
 /**
  * smi_request: generate SMI request
  *
  * Called with smi_data_lock.
  */
-static int smi_request(struct smi_cmd *smi_cmd)
+int dcdbas_smi_request(struct smi_cmd *smi_cmd)
 {
 	cpumask_t old_mask;
 	int ret = 0;
@@ -278,6 +278,7 @@ out:
 	set_cpus_allowed_ptr(current, &old_mask);
 	return ret;
 }
+EXPORT_SYMBOL(dcdbas_smi_request);
 
 /**
  * smi_request_store:
@@ -309,14 +310,14 @@ static ssize_t smi_request_store(struct device *dev,
 	switch (val) {
 	case 2:
 		/* Raw SMI */
-		ret = smi_request(smi_cmd);
+		ret = dcdbas_smi_request(smi_cmd);
 		if (!ret)
 			ret = count;
 		break;
 	case 1:
 		/* Calling Interface SMI */
 		smi_cmd->ebx = (u32) virt_to_phys(smi_cmd->command_buffer);
-		ret = smi_request(smi_cmd);
+		ret = dcdbas_smi_request(smi_cmd);
 		if (!ret)
 			ret = count;
 		break;
@@ -238,11 +238,11 @@ static ssize_t host_control_on_shutdown_store(struct device *dev,
 
 /**
- * smi_request: generate SMI request
+ * dcdbas_smi_request: generate SMI request
  *
  * Called with smi_data_lock.
-- 
Matthew Garrett | mjg59@srcf.ucam.org

^ permalink raw reply related	[flat|nested] 20+ messages in thread

end of thread, other threads:[~2008-12-05  2:08 UTC | newest]

Thread overview: 20+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2008-11-27 16:33 [PATCH 1/2] dcdbas: Export functionality for use in other drivers Matthew Garrett
2008-11-27 16:34 ` [PATCH 2/2] misc: Add dell-laptop driver Matthew Garrett
2008-12-02 17:02   ` Matt Domsch
2008-12-02 17:03     ` Matthew Garrett
2008-12-02 19:50   ` Andrew Morton
2008-12-02 20:05     ` Matthew Garrett
2008-12-02 20:22       ` Andrew Morton
2008-12-02 20:30         ` Matthew Garrett
2008-12-02 20:16     ` [PATCH 2/2 update] " Matthew Garrett
2008-12-03 12:37       ` Alan Jenkins
2008-12-03 13:01       ` none
2008-12-05  2:05         ` Henrique de Moraes Holschuh
2008-12-03 19:14       ` Len Brown
2008-12-03 19:52         ` Matthew Garrett
2008-12-04  9:12           ` Sven Wegener
2008-12-04 11:00           ` Alan Jenkins
2008-12-05  2:08             ` Henrique de Moraes Holschuh
2008-12-02  3:52 ` [PATCH 1/2] dcdbas: Export functionality for use in other drivers Greg KH
2008-12-02  4:03   ` Matthew Garrett
2008-12-02 17:03     ` Matt Domsch

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox